AdvertisementData class

Data advertised by the Peripheral: power level, local name, manufacturer's data, advertised Services

Properties

hashCode → int
The hash code for this object.
no setterinherited
localName → String?
The local name of the Peripheral. Might be different than Peripheral.name.
final
manufacturerData → Uint8List?
The manufacturer data of the peripheral.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceData → Map<String, Uint8List>?
A dictionary that contains service-specific advertisement data.
final
serviceUuids → List<String>?
A list of service UUIDs.
final
solicitedServiceUuids → List<String>?
A list of solicited service UUIDs.
final
txPowerLevel → int?
The transmit power of the peripheral.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited