BleError class

Constructors

BleError.fromJson(Map<String, dynamic> json)

Properties

androidErrorCode → int?
final
attErrorCode → int?
final
characteristicUuid → String?
final
descriptorUuid → String?
final
deviceID → String?
final
errorCode → BleErrorCode
final
hashCode → int
The hash code for this object.
no setterinherited
internalMessage → String?
final
iosErrorCode → int?
final
reason → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceUuid → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited