Descriptor class

Implementers

Constructors

Descriptor.fromJson(Map<String, dynamic> jsonObject, Characteristic characteristic, ManagerForDescriptor manager)

Properties

characteristic → Characteristic
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uuid → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read({String? transactionId}) → Future<Uint8List>
toString() → String
A string representation of this object.
inherited
write(Uint8List value, {String? transactionId}) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
override