DescriptorWithValue class

Inheritance

Constructors

DescriptorWithValue.fromJson(Map<String, dynamic> jsonObject, Characteristic characteristic, ManagerForDescriptor manager)

Properties

characteristic → Characteristic
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uuid → String
finalinherited
value ↔ Uint8List
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read({String? transactionId}) → Future<Uint8List>
inherited
toString() → String
A string representation of this object.
inherited
write(Uint8List value, {String? transactionId}) → Future<void>
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited