ScanResult class

A scan result emitted by the scanning operation, containing Peripheral and AdvertisementData.

Constructors

ScanResult.fromJson(Map<String, dynamic> json, ManagerForPeripheral manager)
factory

Properties

advertisementData → AdvertisementData
A packet of data advertised by the peripheral.
final
hashCode → int
The hash code for this object.
no setterinherited
isConnectable → bool?
An indicator whether the peripheral is connectable (iOS only).
final
overflowServiceUuids → List<String>
A list of UUIDs found in the overflow area of the advertisement data (iOS only).
final
peripheral → Peripheral
final
rssi → int
Signal strength of the peripheral in dBm.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited